@@ -1,7 +1,9 @@
 package Sah::Schema::dbi::connstr;
 
-our $DATE = '2019-01-20'; # DATE
-our $VERSION = '0.001'; # VERSION
+our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
+our $DATE = '2020-03-02'; # DATE
+our $DIST = 'Sah-Schemas-DBI'; # DIST
+our $VERSION = '0.002'; # VERSION
 
 our $schema = [str => {
     summary => 'DBI connection string',
@@ -11,6 +13,13 @@ our $schema = [str => {
 _
     match => '\Adbi:\w+:.+\z',
     'x.completion' => ['dbi_connstr'],
+    examples => [
+        {data=>'', valid=>0},
+        {data=>'dbi:SQLite:dbname=foo', valid=>1},
+        {data=>'DBI:SQLite:dbname=foo', valid=>0},
+        {data=>'dbi:Foo', valid=>0},
+        {data=>'dbi:Foo:bar=baz', valid=>1},
+    ],
 }, {}];
 
 1;
@@ -28,7 +37,21 @@ Sah::Schema::dbi::connstr - DBI connection string
 
 =head1 VERSION
 
-This document describes version 0.001 of Sah::Schema::dbi::connstr (from Perl distribution Sah-Schemas-DBI), released on 2019-01-20.
+This document describes version 0.002 of Sah::Schema::dbi::connstr (from Perl distribution Sah-Schemas-DBI), released on 2020-03-02.
+
+=head1 SYNOPSIS
+
+Sample data:
+
+ ""  # INVALID
+
+ "dbi:SQLite:dbname=foo"  # valid
+
+ "DBI:SQLite:dbname=foo"  # INVALID
+
+ "dbi:Foo"  # INVALID
+
+ "dbi:Foo:bar=baz"  # valid
 
 =head1 DESCRIPTION
 
@@ -54,7 +77,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2019 by perlancar@cpan.org.
+This software is copyright (c) 2020, 2019 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
