@@ -1,7 +1,9 @@
 package Sah::Schemas::DBI;
 
-our $DATE = '2019-01-20'; # DATE
-our $VERSION = '0.001'; # VERSION
+our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
+our $DATE = '2020-03-02'; # DATE
+our $DIST = 'Sah-Schemas-DBI'; # DIST
+our $VERSION = '0.002'; # VERSION
 
 1;
 # ABSTRACT: Schemas related to DBI
@@ -18,7 +20,7 @@ Sah::Schemas::DBI - Schemas related to DBI
 
 =head1 VERSION
 
-This document describes version 0.001 of Sah::Schemas::DBI (from Perl distribution Sah-Schemas-DBI), released on 2019-01-20.
+This document describes version 0.002 of Sah::Schemas::DBI (from Perl distribution Sah-Schemas-DBI), released on 2020-03-02.
 
 =head1 HOMEPAGE
 
@@ -48,7 +50,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2019 by perlancar@cpan.org.
+This software is copyright (c) 2020, 2019 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
